@@ -243,8 +243,8 @@ impl DatabaseConnection {
         struct InMemory;
         impl Access for InMemory {
             fn open(self, db: *mut *mut ffi::sqlite3) -> c_int {
-                let c_memory = str_charstar(":memory:").as_ptr();
-                unsafe { ffi::sqlite3_open(c_memory, db) }
+                let c_memory = str_charstar(":memory:");
+                unsafe { ffi::sqlite3_open(c_memory.as_ptr(), db) }
             }
         }
         DatabaseConnection::new(InMemory)
@@ -266,12 +266,12 @@ impl DatabaseConnection {
                                     -> SqliteResult<(PreparedStatement, usize)> {
         let mut stmt = ptr::null_mut();
         let mut tail = ptr::null();
-        let z_sql = str_charstar(sql).as_ptr();
+        let z_sql = str_charstar(sql);
         let n_byte = sql.len() as c_int;
-        let r = unsafe { ffi::sqlite3_prepare_v2(self.db.handle, z_sql, n_byte, &mut stmt, &mut tail) };
+        let r = unsafe { ffi::sqlite3_prepare_v2(self.db.handle, z_sql.as_ptr(), n_byte, &mut stmt, &mut tail) };
         match decode_result(r, "sqlite3_prepare_v2", maybe(self.detailed, self.db.handle)) {
             Ok(()) => {
-                let offset = tail as usize - z_sql as usize;
+                let offset = tail as usize - z_sql.as_ptr() as usize;
                 Ok((PreparedStatement { stmt: stmt , db: self.db.clone(), detailed: self.detailed }, offset))
             },
             Err(code) => Err(code)
@@ -396,6 +396,12 @@ pub type ParamIx = u16;
 
 impl PreparedStatement {
     /// Begin executing a statement.
+    ///
+    /// An sqlite "row" only lasts until the next call to
+    /// `ffi::sqlite3_step()`, so `ResultSet` has a corresponding
+    /// lifetime constraint, which prevents it `ResultSet` from
+    /// implementing the `Iterator` trait. See the `Query` trait
+    /// for and `Iterator` over query results.
     pub fn execute(&mut self) -> ResultSet {
         ResultSet { statement: self }
     }
@@ -461,9 +467,9 @@ impl PreparedStatement {
         let ix = i as c_int;
         // SQLITE_TRANSIENT => SQLite makes a copy
         let transient = unsafe { mem::transmute(-1 as isize) };
-        let c_value = str_charstar(value).as_ptr();
+        let c_value = str_charstar(value);
         let len = value.len() as c_int;
-        let r = unsafe { ffi::sqlite3_bind_text(self.stmt, ix, c_value, len, transient) };
+        let r = unsafe { ffi::sqlite3_bind_text(self.stmt, ix, c_value.as_ptr(), len, transient) };
         decode_result(r, "sqlite3_bind_text", self.detail_db())
     }
 
@@ -543,10 +549,6 @@ impl<'res> Drop for ResultSet<'res> {
 
 impl<'res:'row, 'row> ResultSet<'res> {
     /// Execute the next step of a prepared statement.
-    ///
-    /// An sqlite "row" only lasts until the next call to `ffi::sqlite3_step()`,
-    /// so we need a lifetime constraint. The unfortunate result is that
-    ///  `ResultSet` cannot implement the `Iterator` trait.
     pub fn step(&'row mut self) -> SqliteResult<Option<ResultRow<'res, 'row>>> {
         let result = unsafe { ffi::sqlite3_step(self.statement.stmt) };
         match Step::from_i32(result) {
@@ -638,22 +640,22 @@ impl<'res, 'row> ResultRow<'res, 'row> {
     }
 
     /// Get `Option<String>` (aka text) value of a column.
-    pub fn column_text(&mut self, col: ColIx) -> Option<String> {
+    pub fn column_text(&self, col: ColIx) -> Option<String> {
         self.column_str(col).map(|s| s.to_string())
     }
 
     /// Get `Option<&str>` (aka text) value of a column.
-    pub fn column_str<'a>(&'a mut self, col: ColIx) -> Option<&'a str> {
+    pub fn column_str<'a>(&'a self, col: ColIx) -> Option<&'a str> {
         self.column_slice(col).and_then(|slice| str::from_utf8(slice).ok() )
     }
 
     /// Get `Option<Vec<u8>>` (aka blob) value of a column.
-    pub fn column_blob(&mut self, col: ColIx) -> Option<Vec<u8>> {
+    pub fn column_blob(&self, col: ColIx) -> Option<Vec<u8>> {
         self.column_slice(col).map(|bs| bs.to_vec())
     }
 
     /// Get `Option<&[u8]>` (aka blob) value of a column.
-    pub fn column_slice<'a>(&'a mut self, col: ColIx) -> Option<&'a [u8]> {
+    pub fn column_slice<'a>(&'a self, col: ColIx) -> Option<&'a [u8]> {
         let stmt = self.rows.statement.stmt;
         let i_col = col as c_int;
         let bs = unsafe { ffi::sqlite3_column_blob(stmt, i_col) } as *const ::libc::c_uchar;
@@ -822,7 +824,7 @@ mod tests {
     fn non_utf8_str() {
         let mut stmt = DatabaseConnection::in_memory().unwrap().prepare("SELECT x'4546FF'").unwrap();
         let mut rows = stmt.execute();
-        let mut row = rows.step().unwrap().unwrap();
+        let row = rows.step().unwrap().unwrap();
         assert_eq!(row.column_str(0), None);
         assert!(str::from_utf8(&[0x45u8, 0x46, 0xff]).is_err());
     }
