@@ -7,12 +7,13 @@ use time::Timespec;
 use sqlite3::{
     DatabaseConnection,
     Query,
+    ResultRow,
     ResultRowAccess,
     SqliteResult,
     StatementUpdate,
 };
 
-#[derive(Debug)]
+#[derive(Debug, Clone)]
 struct Person {
     id: i32,
     name: String,
@@ -50,15 +51,12 @@ fn io() -> SqliteResult<Vec<Person>> {
 
     let mut stmt = try!(conn.prepare("SELECT id, name, time_created FROM person"));
 
-    let mut ppl = vec!();
-    try!(stmt.query(
-        &[], &mut |row| {
-            ppl.push(Person {
-                id: row.get("id"),
-                name: row.get("name"),
-                time_created: row.get(2)
-            });
-            Ok(())
-        }));
-    Ok(ppl)
+    let to_person = |row: &mut ResultRow| Ok(
+        Person {
+            id: row.get("id"),
+            name: row.get("name"),
+            time_created: row.get(2)
+        });
+    let ppl = try!(stmt.query(&[], to_person));
+    ppl.collect()
 }
